"""
Created on 29.11.2021
This is a graphical user interface for the kursversorgung_functions.py file.
@author: baier
"""

from kursversorgung_google_sheets import checkBloombergConnection, callBloombergApi, updateLast, updateSecurityName, \
    updateWechselkurse, checkStatus, ws, wsPP1, updateLastSplits
from tkinter import *
import time
import datetime
import os

running = False  # Global flag
session = False  # Global flag


def main():

    def scanning():
        global running, session
        session = checkBloombergConnection()
        now = (datetime.datetime.now()).strftime('%d.%m.%Y %H:%M:%S')

        if session:  # Only do this if the Stop button has not been clicked
            if running:
                ticker = ws.col_values(1)[1:]
                ticker_pp = wsPP1.col_values(1)[1:]
                df = callBloombergApi(ticker, ticker_pp, fld1='Last_Price', fld2='Last_All_Sessions', fld3='Security_Name',
                                      fld4='EXCH_Market_Status', fld5='EQY_Split_Ratio', fld6='EQY_Split_DT')

                output.insert(END, updateLast(ticker, ticker_pp, df, now) + '\n')
                time.sleep(2.5)
                updateSecurityName(ticker, ticker_pp, df, now)
                time.sleep(2.5)
                updateWechselkurse(now)
                time.sleep(2.5)
                checkStatus(now)
        else:
            output.insert(END, f"{now}: Bloomberg connection could not be established!\n")

        root.after(900000, scanning)  # After 15 Minutes, call scanning again (create a recursive loop) 900000

    def start():
        """Enable scanning by setting the global flag to True."""
        global running, session
        running = True
        now = (datetime.datetime.now()).strftime('%d.%m.%Y %H:%M:%S')
        output.insert(END, f"{now}: Trying to establish connection to Bloomberg API.\n")

        session = checkBloombergConnection()

        if session:
            ticker = ws.col_values(1)[1:]
            ticker_pp = wsPP1.col_values(1)[1:]
            df = callBloombergApi(ticker, ticker_pp, fld1='Last_Price', fld2='Last_All_Sessions', fld3='Security_Name',
                                  fld4='EXCH_Market_Status', fld5='EQY_Split_Ratio', fld6='EQY_Split_DT')

            output.insert(END, f"{now}: Bloomberg connection established!\n\n")
            output.insert(END, updateLastSplits(ticker, df, now) + "\n")
            output.insert(END, updateLast(ticker, ticker_pp, df, now) + '\n')
        else:
            running = False
            output.insert(END, f"{now}: Bloomberg connection could not be established!\n")

    def stop():
        """Stop scanning by setting the global flag to False."""
        global running
        running = False
        now = (datetime.datetime.now()).strftime('%d.%m.%Y %H:%M:%S')
        output.insert(END, now + ": Updating has stopped\n")

    directory = os.path.dirname(__file__)
    root = Tk()
    root.title("Kursversorgung Warrants")
    root.geometry("620x400")
    root.iconbitmap(os.path.join(directory, 'software_update.ico'))

    app = Frame(root)
    app.grid()

    output = Text(root, height=12, width=73)
    start = Button(text="Start updating", command=start)
    stop = Button(text="Stop updating", command=stop)

    start.place(relx=0.5, rely=0.1, anchor=CENTER)
    stop.place(relx=0.5, rely=0.2, anchor=CENTER)
    output.place(relx=0.5, rely=0.5, anchor=CENTER)

    root.after(900000, scanning)  # After 15 Minutes, call scanning 900000
    root.mainloop()


if __name__ == '__main__':
    main()



"""
Created on 02.07.2021
This is a program to monitor all the expiring values within the google sheet containing the Warrants
@author: baier
"""

import os
from pretty_html_table import build_table
import pandas as pd
from dotenv import load_dotenv
from accessOutlookEmail import create_account, send_email
from bs4 import BeautifulSoup as bS
from kursversorgung_google_sheets import create_client_with_scope

load_dotenv()
account = create_account(os.getenv('email_valentin'), os.getenv('password_valentin'))
client = create_client_with_scope()
ws = client.open('KursversorgungWarrants').worksheet('Kurse')


def createPrettyHTMLTable(df):
    indexList = df.index.to_list()

    warrantsDF = pd.DataFrame(columns=['Ticker', 'Beschreibung', 'Anmerkung', 'Restricted', 'Closing', 'Anzahl',
                                       'Laufzeit', 'Strike', 'Last', 'AK', 'PnL', 'PnL in %', 'Broker', 'Status',
                                       'Pricing Underlaying', 'Last Split', 'Split Ratio', 'Zuletzt bearbeitet am',
                                       'Bearbeiter'])
    for idx in indexList:
        to_append = ws.row_values(idx)
        a_series = pd.Series(to_append, index=warrantsDF.columns)
        warrantsDF = warrantsDF.append(a_series, ignore_index=True)

    pretty_html = build_table(warrantsDF, 'blue_light')
    soup = bS(pretty_html, 'lxml')
    table = soup.find_all('table')[0]

    for row in table.find_all('tr'):
        col_marker = 0
        col_marker2 = 0
        cols = row.find_all('td')
        value_list = [x.text.strip() for x in cols]

        for value in value_list:
            if col_marker2 == 10:
                try:
                    value = int(value.replace('.', ''))
                    value = float((value.replace('%', '')).replace(',', '.'))
                except AttributeError: pass

                for col in cols:
                    if col_marker in [10, 11]:
                        if value < 0: col['style'] += '; color: red'
                        elif value > 0: col['style'] += '; color: green'
                    col_marker += 1
            col_marker2 += 1

    return table


def getDailyPnL():
    ticker = ws.col_values(1)[1:]
    pnlabsolut = ws.col_values(11)[1:]
    pnlinpercent = ws.col_values(12)[1:]

    df = pd.DataFrame(list(zip(ticker, pnlabsolut, pnlinpercent)), columns=['Ticker', 'PnL', 'PnL in %'])
    df.index += 2  # setz Index zu Zeilen in Excel

    # edit PnL in %
    df = df[df['PnL in %'] != '0,00%']
    df = df[~df['PnL in %'].str.contains("-", na=False)]
    df['PnL in %'] = df['PnL in %'].str.replace(',', '.').str.replace('%', '')
    df['PnL in %'] = pd.to_numeric(df['PnL in %'])
    df = df[df['PnL in %'] > 30]  # filter by value bigger than 30 percent

    # edit PNL
    df['PnL'] = df['PnL'].str.replace('.', '', regex=True)
    df['PnL'] = pd.to_numeric(df['PnL'])
    df = df[df['PnL'] > 20000]  # filter by value bigger than 20.000
    df = df.sort_values(by=['PnL in %'], ascending=False)

    table = createPrettyHTMLTable(df)

    send_email(account, 'Daily Warrant Report', table, ['dichtl@orcacapital.de', 'grodon@orcacapital.de',
                                                        'koenig@orcacapital.de'])


def main():
    getDailyPnL()


if __name__ == '__main__':
    main()



from dotenv import load_dotenv
from accessOutlookEmail import create_account, send_email
import os

load_dotenv()

# v = create_account(os.getenv('email_valentin'), os.getenv('password_valentin'))
account = create_account(str(os.getenv('email_valentin')), str(os.getenv('password_valentin')))
print(account)



"""
Created on 20.05.2021
This is a program to get all new Values for the provided Tickers in the Google Warrant Spreadsheet
@author: baier
"""
import pandas as pd
import blpapi
import os
from dotenv import load_dotenv
from accessOutlookEmail import create_account, send_email
from kursversorgung_google_sheets.authenticate import create_client_with_scope
from xbbg import blp

load_dotenv()
account = create_account(str(os.getenv('email_valentin')), str(os.getenv('password_valentin')))
recipients = ['schroedl@orcacapital.de', 'kreutmair@orcacapital.de']
client = create_client_with_scope()

ws = client.open('KursversorgungWarrants').worksheet('Kurse')
ws2 = client.open('KursversorgungWarrants').worksheet('Neue Warrants')
ws3 = client.open('KursversorgungWarrants').worksheet('Geschlossene Warrants')
ws4 = client.open('KursversorgungWarrants').worksheet('Währungstabelle')

wsPP1 = client.open('Private Placements').worksheet('Private Placements')
check = True


def checkBloombergConnection():
    options = blpapi.SessionOptions()
    options.setServerHost('localhost')
    options.setServerPort(8194)
    session = blpapi.Session(options).start()
    return session


def callBloombergApi(ticker_list_1: list, ticker_list_2: list, **kwargs):
    set_of_all_tickers = set.union(set(ticker_list_1), set(ticker_list_2))  # create a set of all the tickers
    list_of_all_tickers = list(set_of_all_tickers)
    ticker_with_equity = [f'{ticker.strip()} Equity' for ticker in list_of_all_tickers if ticker != '']

    if kwargs: df = blp.bdp(ticker_with_equity, list(kwargs.values()))
    else: return 'Please specify bloomberg fields you wanna request!'

    df.index = [item[:-7] for item in df.index.tolist()]
    return df


def parseStringToInteger(x):
    myList = []

    for s in x.split():
        if s[0] == '.':
            myList.append(float(s))
        if s.isdigit():
            myList.append(int(s))
        if s == 'for':
            continue

    # print(myList)
    value = (myList[0] / myList[1])
    return value


def logEntry(logfile_name: str, entry_type: str, timestamp: str, **kwargs):
    entry_data = kwargs.get('entry_data', None)
    logfile = open(rf"S:\Kursversorgung Warrents\{logfile_name}.txt", "a")
    new_entry = f'{timestamp} {entry_type}'
    if entry_data is not None:
        for fld in entry_data:
            new_entry = new_entry + ' ' + fld + ','
    logfile.writelines(new_entry)
    logfile.write('\n')


def updateDataType(celllist, check_pnl=False):
    if celllist[3].value == 'FALSE':
        celllist[3].value = False
    else:
        celllist[3].value = True
    if celllist[5].value:
        celllist[5].value = int(celllist[5].value.replace('.', ''))
    if celllist[7].value:
        celllist[7].value = float(celllist[7].value.replace(',', '.'))
    if celllist[8].value:
        celllist[8].value = float(celllist[8].value.replace(',', '.'))
    if celllist[9].value:
        celllist[9].value = float(celllist[9].value.replace(',', '.'))
    if celllist[10].value and check_pnl is False:
        celllist[10].value = int(celllist[10].value.replace('.', ''))
    else:
        celllist[10].value = None
    if celllist[11].value and check_pnl is False:
        celllist[11].value = float((celllist[11].value.replace('%', '')).replace(",", '.')) / 100
    else:
        celllist[11].value = None


def checkStatus(timestamp: str):
    # checke das Kurs-Sheet, ob blanke Warrants drin stehen und verkaufte/geschlossene
    kurse_status = ws.col_values(14)[1:]
    reviewed = ws2.col_values(20)[1:]
    reversed_warrants = ws3.col_values(14)[1:]

    max_rows_new = (len(ws.get_all_values()))
    max_rows_closed = (len(ws3.get_all_values()))
    # For-Loop für geschlossene, verfallene, ausgeübt Warrants        --- VON 1 NACH 3
    for i, item in enumerate(reversed(kurse_status)):
        y = len(kurse_status) + 1 - i
        if item != 'Offen':
            if item == '':
                ws.update_cell(y, 14, 'Offen')
                kurse_status[y - 2] = 'Offen'
            else:
                row_values = ws.row_values(y)
                celllistWS1 = ws.range('A' + str(y) + ':S' + str(y))
                updateDataType(celllistWS1)

                ws3.append_row(['placeholder1'])
                max_rows_closed += 1

                celllistWS3 = ws3.range('A' + str(max_rows_closed) + ':S' + str(max_rows_closed))
                for j, inhalt in enumerate(celllistWS3): inhalt.value = celllistWS1[j].value
                ws3.update_cells(celllistWS3)

                ws.delete_rows(y)
                max_rows_new -= 1

                # insert entry to logfile
                logEntry('LOGFILE', 'ADD to Geschlossene Warrants from Kurse ->', timestamp, entry_data=row_values)

    # For-Loop für Neue Warrants                                      --- VON 2 NACH 1
    for i, item in enumerate(reversed(reviewed)):
        y = len(reviewed) + 1 - i

        if item == 'Eingebucht':
            row_values = ws2.row_values(y)[:-1]
            celllistWS2 = ws2.range('A' + str(y) + ':S' + str(y))
            updateDataType(celllistWS2, True)

            ws.append_row(['placeholder2'])
            max_rows_new += 1

            celllistWS1 = ws.range('A' + str(max_rows_new) + ':S' + str(max_rows_new))
            for j, inhalt in enumerate(celllistWS1): inhalt.value = celllistWS2[j].value
            ws.update_cells(celllistWS1)

            ws2.delete_rows(y)

            # insert entry to logfile
            logEntry('LOGFILE', 'ADD to Kurse from Neue Warrants ->', timestamp, entry_data=row_values)

    # For-Loop für geschlossene Warrants, die wieder geöffnet wurden    --- VON 3 NACH 1
    for i, item in enumerate(reversed(reversed_warrants)):
        y = len(reversed_warrants) + 1 - i

        if item == 'Offen':
            row_values = ws3.row_values(y)

            celllistWS3 = ws3.range('A' + str(y) + ':S' + str(y))
            updateDataType(celllistWS3, True)

            ws.append_row(['placeholder3'])
            max_rows_new += 1

            celllistWS1 = ws.range('A' + str(max_rows_new) + ':S' + str(max_rows_new))
            for j, inhalt in enumerate(celllistWS1): inhalt.value = celllistWS3[j].value
            ws.update_cells(celllistWS1)

            ws3.delete_rows(y)
            max_rows_closed -= 1

            # insert entry to logfile
            logEntry('LOGFILE', 'ADD to Kurse from Geschlossene Warrants ->', timestamp, entry_data=row_values)


def updateWechselkurse(timestamp: str):
    bloombergTicker = ws4.col_values(5)[2:]
    df = blp.bdp(bloombergTicker, ['last_price'])
    kurse = [df.loc[item].at['last_price'] for item in bloombergTicker]

    cell_list = ws4.range('D3:D' + str(len(kurse) + 2))
    for i, val in enumerate(kurse): cell_list[i].value = val

    ws4.update_cells(cell_list)
    ws4.update_cell(1, 7, timestamp)


def updateLast(ticker: list, ticker_pp: list, df: pd.DataFrame, timestamp: str):
    # Update Last in Kursversorgung Warrants
    df = df.fillna({'last_price': 0, 'last_all_sessions': 0})
    # create a Dict for all currencies
    # boerse = ws4.col_values(1)[1:]
    # wechselkurse = ws4.col_values(4)[1:]
    # währungsdict = {}
    # for i, item in enumerate(boerse):
    #    boerse[i] = ' ' + item
    # währungsdict = dict(zip(boerse, wechselkurse))

    # Kursversorgung Warrants Sheet
    priceList = []  # iterate over all tickers, if price is pulled from Bloomberg, add to list, if not add 0
    for item in ticker:
        boersenkuerzel = item[-3:]
        if boersenkuerzel in item and len(boersenkuerzel) == 3:
            # kurs = währungsdict.get(boersenkuerzel)
            # kurs = float(kurs.replace(",", "."))
            try:
                newPrice = df.loc[item].at['last_price']
                if boersenkuerzel == ' US': newPrice = df.loc[item].at['last_all_sessions']
                priceList.append(round(newPrice, 4))
            except (ValueError, KeyError, OSError) as err:
                logEntry('LOGFILE', f'{err} threw an exception', timestamp)
                priceList.append(0)
        else: priceList.append(0)

    cell_list = ws.range('I2:I' + str(len(ticker) + 1))  # insert CELLRANGE into Google worksheet
    for i, val in enumerate(priceList): cell_list[i].value = val  # Update Values in CellList

    # Update Last in Private Placements
    priceList1 = []
    for item in ticker_pp:
        try:
            newPrice = df.loc[item].at['last_price']
            priceList1.append(round(newPrice, 4))
        except (ValueError, KeyError, OSError) as err:
            logEntry('LOGFILE_PP', f'{err} threw an exception', timestamp)
            priceList1.append(0)

    cell_list1 = wsPP1.range('I2:I' + str(len(ticker_pp) + 1))
    for i, val in enumerate(priceList1): cell_list1[i].value = val

    try:
        ws.update_cells(cell_list)
        wsPP1.update_cells(cell_list1)
        ws.update_cell(1, 21, timestamp)
        wsPP1.update_cell(1, 24, timestamp)
        return f'{timestamp}: Last Price was updated correctly'
    except (ValueError, KeyError, OSError) as err:
        return f'{err} was raised in updateLast()'


def updateSecurityName(ticker: list, ticker_pp: list, df: pd.DataFrame, timestamp: str):
    # Update Security Name in Kursversorgung Warrants
    beschreibung = ws.col_values(2)[1:]
    df_tkch = df[df['exch_market_status'] == 'TKCH']
    del df_tkch['security_name']
    global check

    for i, item in enumerate(ticker):
        check = True
        try:
            if item in df_tkch.index and beschreibung[i] != 'TICKER CHANGE':
                ws.update_cell(str(i+2), 2, 'TICKER CHANGE')
                log_data = f'TICKER CHANGE Index: {str(i+2)} = {beschreibung[i]}'
                logEntry('LOGFILE', log_data, timestamp)
                send_email(account, 'Ticker Change Kursversorgung Warrants', log_data, recipients)
                check = False
                continue
            sec_name = df.loc[item].at['security_name']
            if sec_name != beschreibung[i] and beschreibung[i] != 'TICKER CHANGE' and check is True:
                try:
                    ws.update_cell(str(i+2), 2, sec_name)
                    logEntry('LOGFILE', f'NAMECHANGE Index: {str(i+2)} = {beschreibung[i]} TO {sec_name} in Kurse',
                             timestamp)
                except (ValueError, KeyError, OSError) as err:
                    logEntry('LOGFILE', f'{err} was raised', timestamp)
        except (ValueError, KeyError, OSError) as err:
            logEntry('LOGFILE', f'{err} was raised', timestamp)

    # Update Security Name in Private Placements
    beschreibung = wsPP1.col_values(2)[1:]

    for i, item in enumerate(ticker_pp):
        check = True
        try:
            if item in df_tkch.index and beschreibung[i] != 'TICKER CHANGE':
                wsPP1.update_cell(str(i+2), 2, 'TICKER CHANGE')
                log_data = f'TICKER CHANGE Index: {str(i+2)} = {beschreibung[i]}'
                logEntry('LOGFILE_PP', log_data, timestamp)
                send_email(account, 'Ticker Change Private Placements', log_data, recipients)
                check = False
                continue
            sec_name = df.loc[item].at['security_name']
            if sec_name != beschreibung[i] and beschreibung[i] != 'TICKER CHANGE' and check is True:
                try:
                    wsPP1.update_cell(str(i+2), 2, sec_name)
                    logEntry('LOGFILE_PP', f'NAMECHANGE Index: {str(i+2)} = {beschreibung[i]} TO {sec_name} in Kurse',
                             timestamp)
                except (ValueError, KeyError, OSError) as err:
                    logEntry('LOGFILE_PP', f'{err} was raised', timestamp)
        except (ValueError, KeyError, OSError) as err:
            logEntry('LOGFILE_PP', f'{err} was raised', timestamp)


def updateLastSplits(ticker: list, df: pd.DataFrame, timestamp: str):
    pd.options.mode.chained_assignment = None  # default='warn'
    df = df[['eqy_split_ratio', 'eqy_split_dt']].dropna()

    df['eqy_split_dt'] = pd.to_datetime(df['eqy_split_dt'], format='%Y-%m-%d')
    df['eqy_split_dt'] = df['eqy_split_dt'].map(lambda x: x.strftime('%d.%m.%Y'))
    df['eqy_split_ratio'] = df['eqy_split_ratio'].map(lambda x: parseStringToInteger(x))

    cell_listDate = ws.range('P2:P' + str(len(ticker) + 1))
    cell_listRatio = ws.range('Q2:Q' + str(len(ticker) + 1))

    for i, item in enumerate(ticker):  # check if Ticker is in the modified DF, which only contains EQYs with Splits
        if item not in df.index:
            cell_listRatio[i].value = None
            cell_listDate[i].value = None
        else:  # Set the Cell Value to the new found Split
            if cell_listDate[i].value != df.loc[item].at['eqy_split_dt']:
                cell_listRatio[i].value = df.loc[item].at['eqy_split_ratio']
                cell_listDate[i].value = df.loc[item].at['eqy_split_dt']
                log_data = f'SPLIT Index: {str(i + 2)} = {item}'
                logEntry('LOGFILE', log_data, timestamp)  # Log every Split, which was insert
                send_email(account, 'Split in Kursversorgung Warrants', log_data, recipients)

    ws.update_cells(cell_listDate)  # Update Cell Lists in GoogleSheet
    ws.update_cells(cell_listRatio)
    return f"{timestamp}: Program has updated Last Splits for all Equities"



from gspread import authorize
from oauth2client.service_account import ServiceAccountCredentials


def create_keyfile_dict():
    variables_keys = {
        "type": "service_account",
        "project_id": "kursversorgung-warrants",
        "private_key_id": "001902bc3d2b4f52449dabdbd024b0634634db90",
        "private_key": "-----BEGIN PRIVATE KEY-----\nMIIEvAIBADANBgkqhkiG9w0BAQEFAASCBKYwggSiAgEAAoIBAQC56DxGENrwtw6y\naxFb1qPcdKTTnzqImbl9EUfLZLcz1EccuUuieXefTzB9uECe43Z25AsNXCImq1M0\npEGLfOS+EN54E6jocf5ccGOMiafUCUgbeX43IPiI8nakDpkrn8uOsMA0Vxd0yPdY\nzZmJMXC6LbOi+2ISGQCpWSg4XWKwMnhsrnZuUXGJDBLWEdfmZoQOh9XSnHJSDAcm\n+cnT0wDMW5+IVIAvcBgc8Vg1mwX8OFARZIl+d9kRZp2/wtvSZJe4fn7BN3B3UMRr\n/ykA9bY7EiXutb4O6do81D9GbKkOQfze9CKt+uRhZBesyToBLeh0HCiYtJv35VlF\nIzqR2iZ3AgMBAAECggEAUpGKX6Yxz5LGRMkX8x2wNoRaBqGkWjJId3ta00O+uJbS\nJLhJlvZzAj8mLthMXyVwoppjLEJc6qbSNEG12NGWOLJ+VH+K1/51NjI2jJ9A+oRK\n0eUSgUK0EAL8XZ4cOotk2dG39CcwRE7TyM28IPpj8lTFAaC77ITNTenK2snjQJTP\nfTsO3ZU4qD3+hs4LY610xJ9Jslsy7aspDPkBL4zP1oM8jz1mX2hMr1megVs3iqzr\n3XDMdXCpT60PXRUi0oUx8DLHT/9MnEaDvykwmFLtzEjKjdOT++9sgdQ6fk4GAnJr\nLlZbP6EWqI6kCZ2r5R9WYcOiiPoa+MnIvnhrLZ0ENQKBgQDtU+HM5RaokSSMON2s\nKpkH0txYcPnG6kuMIzGwBn2Z0gZSZzYobABi3+i5B51oS6gh7AJ+KnjIZL3UdgLB\noGmczPBh0no4LX8hf3Szr6+zJyPE0LzSwcExA54OHAXZ9uLY/S0bxCcarIvCnbdI\n6IueaHP1U3hu0ZCsLEaRtthPUwKBgQDIiKvWqXDEO4uYCei/a+JO0cp9QcoqUo0A\nZfkGoOff+fVxsdlhX6a/BGHsRbV0OyjG+2lxFF9UE4SOFDlgkAHl1Kjtx72/IwTK\n0QWbl9b/CyGJbGekD9mM96W8apQVMAUs1l65/hnmJMs0dT+VUEcbccVjYMZ7epI+\nwwV/b2u7zQKBgCYZdkFncZjEHELqiiOufvyzjC4ijOazDEfGCp8Am79K6TrnWNlq\nZTF6UqkJoOpyYt53Pfs1JEi/a34lJ9Ifx3Slrd12ZaqJG0SsanbCOImhOevJutZ2\nxmXw97m6I/JW4RoGouw3NDPjCVjH6vmoY2mdySfUK5xWxkvtm7Ke0OEDAoGALvc7\nb7INdBgSEJC5jyOARD+EMiPXamQdG+vGEBRdWiqbnn4t0E1rqy8mlASbg9ZbLYcy\nYcaIsRNFJ1V7Pq9bkm1lBxOR0BMuiyW7L363XtJHj3zxJQ6FQCu8CE3Z0sCFZcPr\nOZpWjH0vjmCrfJfpn3bc6PKAaekCGWrpfbglvj0CgYAlfUjvtHKHqgKCkca/3Ssq\njawqSls4C4hvRIzRnI+F0Z9fR/dFXd/PY3xVrU9O4B1KiiFaK8INzZkKTg4dKC86\n+L2vgmVbaMOWI81I86iO6VCJd4lQ96WZkyCtZrCFZ+6XmQTxM8tZ5msG4gEZkeEP\n6IkwP+9XHEyJe0IN74WZ/g==\n-----END PRIVATE KEY-----\n",
        "client_email": "autoupdate@kursversorgung-warrants.iam.gserviceaccount.com",
        "client_id": "112479920726975497823",
        "auth_uri": "https://accounts.google.com/o/oauth2/auth",
        "token_uri": "https://oauth2.googleapis.com/token",
        "auth_provider_x509_cert_url": "https://www.googleapis.com/oauth2/v1/certs",
        "client_x509_cert_url": "https://www.googleapis.com/robot/v1/metadata/x509/autoupdate%40kursversorgung-warrants.iam.gserviceaccount.com"
    }
    return variables_keys


def create_client_with_scope():
    scope = ['https://www.googleapis.com/auth/spreadsheets', 'https://www.googleapis.com/auth/drive.file',
             'https://www.googleapis.com/auth/drive']
    creds = ServiceAccountCredentials.from_json_keyfile_dict(create_keyfile_dict(), scope)

    return authorize(creds)
